<?php
/**
 * Catch Box functions and definitions
 *
 * Sets up the theme and provides some helper functions. Some helper functions
 * are used in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 *
 * The first function, catchbox_setup(), sets up the theme by registering support
 * for various features in WordPress, such as post thumbnails, navigation menus, and the like.
 *
 * When using a child theme (see http://codex.wordpress.org/Theme_Development and
 * http://codex.wordpress.org/Child_Themes), you can override certain functions
 * (those wrapped in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before the parent
 * theme's file, so the child theme functions would be used.
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are instead attached
 * to a filter or action hook. The hook can be removed by using remove_action() or
 * remove_filter() and you can attach your own function to the hook.
 *
 * We can remove the parent theme's hook only after it is attached, which means we need to
 * wait until setting up the child theme:
 *
 * <code>
 * add_action( 'after_setup_theme', 'my_child_theme_setup' );
 * function my_child_theme_setup() {
 *     // We are providing our own filter for excerpt_length (or using the unfiltered value)
 *     remove_filter( 'excerpt_length', 'catchbox_excerpt_length' );
 *     ...
 * }
 * </code>
 *
 * For more information on hooks, actions, and filters, see http://codex.wordpress.org/Plugin_API.
 *
 * @package Catch Themes
 * @subpackage Catch_Box_Pro
 * @since Catch Box Pro 1.0
 */


if ( ! function_exists( 'catchbox_content_width' ) ) :
	/**
	 * Set the content width in pixels, based on the theme's design and stylesheet.
	 *
	 * Priority 0 to make it available to lower priority callbacks.
	 *
	 * @global int $content_width
	 */
	function catchbox_content_width() {
		$layout  = catchbox_get_theme_layout();

		$content_width = 800;

		if ( 'no-sidebar-full-width' == $layout || is_page_template( 'page-fullwidth.php' ) ) {
			$content_width = 880; /* pixels */
		}
		elseif ( 'no-sidebar' == $layout || is_page_template( 'page-disable-sidebar.php' ) ) {
			$content_width = 660; /* pixels */
		}
		elseif ( 'no-sidebar-one-column' == $layout || is_page_template( 'page-onecolumn.php' ) ) {
			$content_width = 620; /* pixels */
		}

		$GLOBALS['content_width'] = apply_filters( 'catchbox_content_width', $content_width );
	}
endif;
add_action( 'after_setup_theme', 'catchbox_content_width', 0 );


if ( ! function_exists( 'catchbox_setup' ) ):
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * To override catchbox_setup() in a child theme, add your own catchbox_setup to your child theme's
 * functions.php file.
 *
 * @uses load_theme_textdomain() For translation/localization support.
 * @uses add_editor_style() To style the visual editor.
 * @uses add_theme_support() To add support for post thumbnails, automatic feed links,custom headers and backgrounds.
 * @uses register_nav_menus() To add support for navigation menus.
 * @uses register_default_headers() To register the default custom header images provided with the theme.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 *
 * @since Catch Box 1.0
 */
function catchbox_setup() {

	/* Catch Box is now available for translation.
	 * Add your files into /languages/ directory.
	 * @see http://codex.wordpress.org/Function_Reference/load_theme_textdomain
	 */
	load_theme_textdomain( 'catch-box', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to <head>.
	add_theme_support( 'automatic-feed-links' );

	/**
	 * Setup title support for theme
	 * Supported from WordPress version 4.1 onwards
	 * More Info: https://make.wordpress.org/core/2014/10/29/title-tags-in-4-1/
	 */
	add_theme_support( 'title-tag' );

	// Add support for a variety of post formats
	add_theme_support( 'post-formats', array( 'aside', 'link', 'gallery', 'status', 'quote', 'image', 'video', 'chat' ) );

	// Load up theme options defaults
	require( get_template_directory() . '/inc/panel/catchbox-themeoptions-defaults.php' );

	// Load up our theme options page and related code.
	require( get_template_directory() . '/inc/panel/theme-options.php' );

	// Register Sidebar and Widget.
	require( get_template_directory() . '/inc/catchbox-widgets.php' );

	// Load up our Catch Box Pro's Functions
	require( get_template_directory() . '/inc/catchbox-functions.php' );

	// Load up our Simple Catch Pro's metabox
	require( get_template_directory() . '/inc/catchbox-metabox.php' );

	// Load up our Simple Catch Pro's customizer
	require( get_template_directory() . '/inc/panel/customizer/customizer.php' );

	// Get Theme Options data
	global $catchbox_options_settings;
    $options = $catchbox_options_settings;

	// Load up our new theme update notifier
	if ( $options[ 'disable_notifier' ] == '0' ) {
		require( get_template_directory() . '/inc/catchthemes-update-notifier.php' );
	}

	/**
     * This feature enables custom-menus support for a theme.
     * @see http://codex.wordpress.org/Function_Reference/register_nav_menus
     */
	register_nav_menus(array(
		'primary' 	=> __( 'Primary Menu', 'catch-box' ),
	   	'secondary'	=> __( 'Secondary Menu', 'catch-box' ),
		'footer'	=> __( 'Footer Menu', 'catch-box' )
	) );

	 /* Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style();

	/**
     * This feature enables Jetpack plugin Infinite Scroll
     */
    add_theme_support( 'infinite-scroll', array(
		'type'           => 'click',
        'container'      => 'content',
        'footer_widgets' => array( 'sidebar-2', 'sidebar-3', 'sidebar-4' ),
        'footer'         => 'page',
    ) );

	// Add support for custom backgrounds
	// WordPress 3.4+
	if ( function_exists( 'get_custom_header') ) {
		add_theme_support( 'custom-background' );
	}

	/**
     * This feature enables post-thumbnail support for a theme.
     * @see http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
     */
	add_theme_support( 'post-thumbnails' );

	//featued posts
	add_image_size( 'featured-slider-larger', 980, 400, true );
	add_image_size( 'featured-slider', 640, 318, true ); // Used for featured posts if a large-feature doesn't exist

	//@remove Remove check when WordPress 4.8 is released
	if ( function_exists( 'has_custom_logo' ) ) {
		/**
		* Setup Custom Logo Support for theme
		* Supported from WordPress version 4.5 onwards
		* More Info: https://make.wordpress.org/core/2016/03/10/custom-logo/
		*/
		add_theme_support( 'custom-logo',
			array(
		   		'height'      => 300,
	 			'width'       => 125,
	 			'flex-height' => true,
			)
		);
	}

}
endif; // catchbox_setup

add_action( 'after_setup_theme', 'catchbox_setup' );


if ( ! function_exists( 'catchbox_get_theme_layout' ) ) :
	/**
	 * Returns Theme Layout prioritizing the meta box layouts
	 *
	 * @uses  get_options
	 *
	 * @action wp_head
	 *
	 * @since Catch Box 4.6
	 */
	function catchbox_get_theme_layout() {
		$id = '';

		global $post, $wp_query;

	    // Front page displays in Reading Settings
		$page_on_front  = get_option('page_on_front') ;
		$page_for_posts = get_option('page_for_posts');

		// Get Page ID outside Loop
		$page_id = $wp_query->get_queried_object_id();

		// Blog Page or Front Page setting in Reading Settings
		if ( $page_id == $page_for_posts || $page_id == $page_on_front ) {
	        $id = $page_id;
	    }
	    else if ( is_singular() ) {
	 		if ( is_attachment() ) {
				$id = $post->post_parent;
			}
			else {
				$id = $post->ID;
			}
		}

		//Get appropriate metabox value of layout
		if ( '' != $id ) {
			$layout = get_post_meta( $id, 'catchbox-sidebarlayout', true );
		}
		else {
			$layout = 'default';
		}

		//Load options data
		global $catchbox_options_settings;
   		$options = $catchbox_options_settings;

   		//check empty and load default
		if ( empty( $layout ) || 'default' == $layout ) {
			$layout = $options['sidebar_layout'];
		}

		return $layout;
	}
endif; //catchbox_get_theme_layout


/**
 * Migrate Logo to New WordPress core Custom Logo
 *
 *
 * Runs if version number saved in theme_mod "logo_version" doesn't match current theme version.
 */
function catchbox_logo_migrate() {
	$ver = get_theme_mod( 'logo_version', false );

	// Return if update has already been run
	if ( version_compare( $ver, '3.6' ) >= 0 ) {
		return;
	}

	// If a logo has been set previously, update to use logo feature introduced in WordPress 4.5
	if ( function_exists( 'the_custom_logo' ) ) {
		$header_image = get_header_image();

		if ( ! empty( $header_image ) ) {
			// Since previous logo was stored a URL, convert it to an attachment ID
			$logo = attachment_url_to_postid( $header_image );

			if ( is_int( $logo ) ) {
				set_theme_mod( 'custom_logo', $logo );
			}
		}

  		// Update to match logo_version so that script is not executed continously
		set_theme_mod( 'logo_version', '3.6' );
	}
}
add_action( 'after_setup_theme', 'catchbox_logo_migrate' );


/**
 * Migrate Custom Favicon to WordPress core Site Icon
 *
 * Runs if version number saved in theme_mod "site_icon_version" doesn't match current theme version.
 */
function catchbox_site_icon_migrate() {
	$ver = get_theme_mod( 'site_icon_version', false );

	//Return if update has already been run
	if ( version_compare( $ver, '3.6' ) >= 0 ) {
		return;
	}

	/**
	 * Get Theme Options Values
	 */
	global $catchbox_options_settings;
   	$options = $catchbox_options_settings;

   	// If a logo has been set previously, update to use logo feature introduced in WordPress 4.5
	if ( function_exists( 'has_site_icon' ) ) {
		if( isset( $options['fav_icon'] ) && '' != $options['fav_icon'] ) {
			// Since previous logo was stored a URL, convert it to an attachment ID
			$site_icon = attachment_url_to_postid( $options['fav_icon'] );

			if ( is_int( $site_icon ) ) {
				update_option( 'site_icon', $site_icon );
			}
		}

	  	// Update to match site_icon_version so that script is not executed continously
		set_theme_mod( 'site_icon_version', '3.6' );
	}
}
add_action( 'after_setup_theme', 'catchbox_site_icon_migrate' );


/**
 * Adds support for a custom header image.
 */
require( get_template_directory() . '/inc/custom-header.php' );

/**
 * Custom Menus
 */
require get_template_directory() . '/inc/catchbox-menus.php';

/**
 * Add Support for WooCommerce Plugin
 */
if ( class_exists( 'woocommerce' ) ) {
	add_theme_support( 'woocommerce' );
    require( get_template_directory() . '/inc/catchbox-woocommerce.php' );
}


/**
 * Add Support for mqTranslate and qTranslate Plugin
 */
if ( in_array( 'qtranslate/qtranslate.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ||
in_array( 'mqtranslate/mqtranslate.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
	require( get_template_directory() . '/inc/catchbox-qtranslate.php' );
}



/**
 * Add Support for WPML, qTranslate X & Polylang Plugin
 */
if ( defined( 'ICL_SITEPRESS_VERSION' ) || defined( 'QTX_VERSION' ) || class_exists( 'Polylang' ) ) {
	require( get_template_directory() . '/inc/catchbox-wpml.php' );
}


/**
 * Checks if there are options already present from Catch Box free version and adds it to the Adventurous Pro theme options
 *
 * @since Catch Box Pro 4.6
 * @hook after_theme_switch
 */
function catchbox_setup_options() {
	//Perform action only if theme_mods_theme_mods_catchbox-pro does not exist
	if( !get_option( 'theme_mods_catch-box-pro' ) ) {
		//Perform action only if theme_mods_catchbox free version exists
		if ( $catchbox_free_options = get_option ( 'theme_mods_catch-box' ) ) {
			update_option('theme_mods_catch-box-pro', $catchbox_free_options );
		}
	}
}
add_action( 'after_switch_theme', 'catchbox_setup_options' );
